Revisions [WIP]
===============
|Build Status| |PyPI VER| |PyPI DW| |PyPI L|

Revisions lets you mock Python Requests with an explicitly versioned cache
control. Revisions is inspired from ``responses`` and ``requests-cache``, but
is developed to focus on a simpler API.

**WIP**


.. |Build Status| image:: https://travis-ci.org/PrashntS/revisions.svg?branch=master
   :target: https://travis-ci.org/PrashntS/revisions
.. |PyPI V| image:: https://img.shields.io/pypi/v/revisions.svg
   :target: https://pypi.python.org/pypi/revisions
.. |PyPI DW| image:: https://img.shields.io/pypi/dw/revisions.svg
   :target: https://pypi.python.org/pypi/revisions
.. |PyPI VER| image:: https://img.shields.io/pypi/pyversions/revisions.svg
   :target: https://pypi.python.org/pypi/revisions
.. |PyPI L| image:: https://img.shields.io/pypi/l/revisions.svg
   :target: https://pypi.python.org/pypi/revisions
.. |PyPI S| image:: https://img.shields.io/pypi/status/revisions.svg
   :target: https://pypi.python.org/pypi/revisions
